/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |            (DATASET 0002: CLIENT RECORDS ABSTRACTION DATA)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE mode      1='(1) Hospital Inpatient' 2='(2) Residential'
                  3='(3) Outpatient Meth.Maintenance' 4='(4) Outpatient Drug-Free' ;
  VALUE utype     1='(1) Drug Treatment Unit' 3='(3) Both Alc/Drug Treatment' ;
  VALUE environm  1='(1) Hospital Inpatient' 2='(2) Residental Care'
                  3='(3) Outpatient Care' ;
  VALUE dead      0='(0) Alive at time of follow-up' 1='(1) Deceased' ;
  VALUE resp      0='(0) Non-respondent in follow-up' 1='(1) Respondent in follow-up' ;
  VALUE disp      71='(71) Respondents' 73='(73) Deceased' 86='(86) Language problem'
                  87='(87) Incapacitated' 89='(89) Out of scope' 93='(93) Unlocatable'
                  94='(94) Unavailable' 95='(95) Refused' 96='(96) Refusal by prison'
                  99='(99) Final other NIR' ;
  VALUE clientyp  -3='(-3) MISSING' 1='(1) Hospital In-Patient' 2='(2) Residential'
                  3='(3) Out-Patient Detox/Maintenance' 4='(4) Out-Patient Drug-free'
                  5='(5) Alcohol only' 7='(7) Combination'
                  9='(9) Unknown/Unable to determine' ;
  VALUE q3_wait   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q4_plan   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q5_prim   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Self' 2='(2) Family'
                  3='(3) Friend/acquaintance' 4='(4) Clergy' 5='(5) School'
                  6='(6) Social service agency'
                  7='(7) Employee Assistance Program (EAP)'
                  8='(8) Employer (other than EAP)' 9='(9) Legal system-court order'
                  10='(10) Legal system-voluntary' 11='(11) Legal system-unspecified'
                  12='(12) Private physician' 13='(13) Community mental health center'
                  14='(14) Other health professional/provider'
                  15='(15) Another alcohol/drug abuse tx program'
                  16='(16) Other (SPECIFY)' ;
  VALUE q6_prim   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED'
                  1='(1) Public subsidy' 2='(2) Philanthropy' 3='(3) No payment unspe'
                  4='(4) Self-pay' 5='(5) HMO or other pre-paid plan'
                  6='(6) Private health insurance' 7='(7) Medicaid' 8='(8) Medicare'
                  10='(10) CHAMPUS' 11='(11) VA' 12='(12) Social services'
                  14='(14) Other (SPECIFY)' ;
  VALUE q7_secn   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED'
                  1='(1) Public subsidy' 2='(2) Philanthropy' 3='(3) No payment unspe'
                  4='(4) Self-pay' 5='(5) HMO or other pre-paid plan'
                  6='(6) Private health insurance' 7='(7) Medicaid' 8='(8) Medicare'
                  9='(9) DOD' 10='(10) CHAMPUS' 11='(11) VA' 12='(12) Social services'
                  13='(13) Public housing/home relief' 14='(14) Other (SPECIFY)' ;
  VALUE q10_age   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 57='(57) 57-64' 65='(65) 65-74'
                  75='(75) 75+' ;
  VALUE q11gend   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Male' 2='(2) Female' ;
  VALUE q12race   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  2='(2) American Indian or Alaskan Native'
                  3='(3) Asian or Pacific Islander' 4='(4) Black (Afro-American)'
                  5='(5) White' 6='(6) Other (SPECIFY)' ;
  VALUE q13ethn   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Hispanic'
                  2='(2) Not of Hispanic origin' ;
  VALUE q14msta   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Never married'
                  2='(2) Married/common law' 3='(3) Widowed' 4='(4) Separated/divorced'
                  5='(5) Single' 6='(6) Other (SPECIFY)' ;
  VALUE q15chld   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q16chlv   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q17arng   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) No stable arrange. (include homeless, sh'
                  2='(2) With partner/spouse' 3='(3) With parent(s)'
                  4='(4) With other family' 5='(5) With unrelated other(s)'
                  6='(6) With children but no other adult' 7='(7) Alone'
                  8='(8) Controlled environment' 9='(9) Other (SPECIFY)' ;
  VALUE q18edu    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Less than 8 years'
                  2='(2) 8-11 Years' 3='(3) Less than high school grad., NOS'
                  4='(4) High school graduate/GED' 5='(5) Some college'
                  6='(6) College graduate' 7='(7) Postgraduate' 8='(8) Other (SPECIFY)' ;
  VALUE q19stu    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q20empl   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Full-time (35 hrs/wk or more)'
                  2='(2) Part-time (less than 35 hrs/wk)' 3='(3) Employed, NOS'
                  4='(4) Keeping house, not otherwise employed'
                  5='(5) Unemployed, retired' 6='(6) Unemployed, disabled'
                  7='(7) Unemployed, NOS' 8='(8) Other (SPECIFY)' ;
  VALUE q22dwi    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q23othr   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q24jail   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q25trtmn  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE q26hosp   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q27med    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q28hist   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q29abuse  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q30preg   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) NOT APPLICABLE, client is male' 2='(2) Not pregnant'
                  3='(3) Pregnant' ;
  VALUE q31prob   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Single drug abuse only (exclud. alcohol)'
                  2='(2) Polydrug abuse only (excluding alcohol)'
                  3='(3) Alcohol abuse only'
                  4='(4) Alcohol & abuse of one other drug combi'
                  5='(5) Alcohol & abuse of 2 or more other drug'
                  6='(6) Other (SPECIFY)' ;
  VALUE q32prin   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Single drug abuse only (exclud. alcohol)'
                  2='(2) Polydrug abuse only (excluding alcohol)'
                  3='(3) Alcohol abuse only'
                  4='(4) Alcohol and other drug abuse combined'
                  5='(5) Other (SPECIFY)' ;
  VALUE q34hiv    -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Negative'
                  2='(2) Positive' 3='(3) Suspected' 4='(4) Other (SPECIFY)' ;
  VALUE q34ainf   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q35a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q35b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q35c      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q36a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q36b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q36c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q37a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q37b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q37c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q38a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q38b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q38c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q39a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q39b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q39c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q40a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q40b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q40c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q41a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q41b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q41c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q42a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q42b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q42c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q43a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q43b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q43c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q44a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q44b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q44c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q45a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q45b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q45c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q46a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q46b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q46c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q47a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q47b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q47c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q48a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q48b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q48c      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q49a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q49b      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q49c      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q50a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q50b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q50c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q51a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q51b      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q51c      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q52drug   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) No drug of choice'
                  35='(35) Cocaine' 36='(36) Crack' 37='(37) Heroin'
                  38='(38) Non-treatment methadone' 39='(39) Other opiates/synthetics'
                  40='(40) Barbiturates' 41='(41) Benzodiazepines'
                  42='(42) Other sedatives/hypnotics' 43='(43) Methamphetamines'
                  44='(44) Other amphetamines' 45='(45) Marijuana/hashish/THC'
                  46='(46) PCP/LSD' 48='(48) Inhalants' 49='(49) Over the counter (SPECIFY)'
                  50='(50) Alcohol' 51='(51) Other (SPECIFY)' ;
  VALUE q53int    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q53aduse  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q53bfre   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Daily'
                  2='(2) Regularly but not daily' 3='(3) Sporadically' ;
  VALUE q54num    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 15='(15) 15+' ;
  VALUE q55postv  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 15='(15) 15+' ;
  VALUE q56test   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q56_t1ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Urine'
                  2='(2) Serum/Blood' 3='(3) Other (SPECIFY)' ;
  VALUE q56_t2ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Urine'
                  2='(2) Serum/Blood' 3='(3) Other (SPECIFY)' ;
  VALUE q56_monf  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q56_dayf  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q56_yr1f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q56_mo0f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q56_da0f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q56_yr2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q56a1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56a2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56b1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56b2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56c1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56c2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56d1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56d2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56e1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56e2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56f1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56f2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56g1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56g2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56h1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56h2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56i1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56i2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56j1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56j2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56k1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56k2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56l1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  2='(2) Test negative/not applicable' ;
  VALUE q56l2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  2='(2) Test negative/not applicable' ;
  VALUE q56m1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56m2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56n1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56n2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56o1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q56o2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Test positive' 2='(2) Test negative/not applicable' ;
  VALUE q57totn   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 11='(11) 11+' ;
  VALUE q57ayrn   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58past   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q58_pra   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED'
                  1='(1) Cocaine (excluding crack)' 2='(2) Crack' 3='(3) Heroin'
                  4='(4) Non-treatment methadone' 5='(5) Other opiates/synthetics'
                  7='(7) Benzodiazepines' 8='(8) Other sedatives/hypnotics'
                  9='(9) Methamphetamines' 11='(11) Marijuana/Hashish/TCP'
                  12='(12) PCP/LSD' 14='(14) Inhalants' 15='(15) Alcohol'
                  16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)'
                  97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_seca  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Cocaine (excluding crack)' 2='(2) Crack' 3='(3) Heroin'
                  4='(4) Non-treatment methadone' 5='(5) Other opiates/synthetics'
                  6='(6) Barbiturates' 7='(7) Benzodiazepines'
                  8='(8) Other sedatives/hypnotics' 9='(9) Methamphetamines'
                  10='(10) Other amphetamines' 11='(11) Marijuana/Hashish/TCP'
                  12='(12) PCP/LSD' 14='(14) Inhalants' 15='(15) Alcohol'
                  16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)'
                  19='(19) No secondary drug use' 97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_faa   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q58_rea   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Completed planned treatment services'
                  2='(2) Not complete tx, referred elsewhere'
                  3='(3) Not complete tx, administration choice'
                  4='(4) Not complete tx, participant choice'
                  5='(5) Not complete tx, choice not mentioned' 6='(6) Incarcerated'
                  7='(7) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_prb   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Cocaine (excluding crack)' 2='(2) Crack'
                  3='(3) Heroin' 5='(5) Other opiates/synthetics' 7='(7) Benzodiazepines'
                  9='(9) Methamphetamines' 11='(11) Marijuana/Hashish/TCP'
                  15='(15) Alcohol' 16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)'
                  97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_secb  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Cocaine (excluding crack)' 2='(2) Crack' 3='(3) Heroin'
                  4='(4) Non-treatment methadone' 7='(7) Benzodiazepines'
                  11='(11) Marijuana/Hashish/TCP' 15='(15) Alcohol'
                  16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)'
                  19='(19) No secondary drug use' 97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_fab   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here'
                  2='(2) Elsewhere' ;
  VALUE q58_reb   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Completed planned treatment services'
                  2='(2) Not complete tx, referred elsewhere'
                  3='(3) Not complete tx, administration choice'
                  4='(4) Not complete tx, participant choice'
                  5='(5) Not complete tx, choice not mentioned' 6='(6) Incarcerated'
                  7='(7) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_prc   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Cocaine (excluding crack)' 2='(2) Crack' 3='(3) Heroin'
                  5='(5) Other opiates/synthetics' 9='(9) Methamphetamines'
                  11='(11) Marijuana/Hashish/TCP' 15='(15) Alcohol'
                  16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)'
                  97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_secc  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Cocaine (excluding crack)' 7='(7) Benzodiazepines'
                  11='(11) Marijuana/Hashish/TCP' 15='(15) Alcohol'
                  16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)'
                  19='(19) No secondary drug use' 97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_fac   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here'
                  2='(2) Elsewhere' ;
  VALUE q58_rec   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Completed planned treatment services'
                  2='(2) Not complete tx, referred elsewhere'
                  3='(3) Not complete tx, administration choice'
                  4='(4) Not complete tx, participant choice' ;
  VALUE q58_prd   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Cocaine (excluding crack)' 3='(3) Heroin' 15='(15) Alcohol'
                  17='(17) Combination alcohol and other drug'
                  18='(18) Sub. abuse/mental ill. (dual diag.)' ;
  VALUE q58_secd  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  11='(11) Marijuana/Hashish/TCP'
                  16='(16) Polydrug (excluding alcohol)'
                  17='(17) Combination alcohol and other drug'
                  19='(19) No secondary drug use' 97='(97) Other (SPECIFY IN COMMENTS)' ;
  VALUE q58_fad   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here'
                  2='(2) Elsewhere' ;
  VALUE q58_red   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Completed planned treatment services'
                  2='(2) Not complete tx, referred elsewhere' ;
  VALUE q58_pre   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Cocaine (excluding crack)' ;
  VALUE q58_sece  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 15='(15) Alcohol' ;
  VALUE q58_fae   -3='(-3) MISSING' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q58_ree   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Completed planned treatment services' ;
  VALUE q58_prf   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_secf  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_faf   -3='(-3) MISSING' 2='(2) Elsewhere' ;
  VALUE q58_ref   -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Completed planned treatment services' ;
  VALUE q58_prg   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_secg  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_fag   -3='(-3) MISSING' 2='(2) Elsewhere' ;
  VALUE q58_reg   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_prh   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_sech  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_fah   -3='(-3) MISSING' 2='(2) Elsewhere' ;
  VALUE q58_reh   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_pri   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_seci  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_fai   -3='(-3) MISSING' 2='(2) Elsewhere' ;
  VALUE q58_rei   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q58_prj   -3='(-3) MISSING' ;
  VALUE q58_secj  -3='(-3) MISSING' ;
  VALUE q58_faj   -3='(-3) MISSING' ;
  VALUE q58_rej   -3='(-3) MISSING' ;
  VALUE q59_ser   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Not given' 2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q59_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q59_no    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 50='(50) 50+' ;
  VALUE q60_ser   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Not given' 2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q60_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q60_no    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 50='(50) 50+' ;
  VALUE q61_ser   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Not given' 2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q61_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q61_no    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 50='(50) 50+' ;
  VALUE q62_ser   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Not given' 2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q62_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q62_no    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 50='(50) 50+' ;
  VALUE q63_ser   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Not given' 2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q63_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q64_ser   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Not given'
                  2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q64_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q65_ser   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Not given'
                  2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q65_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q66_ser   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Not given'
                  2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q66_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q67_ser   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Not given'
                  2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q67_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q68_ser   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Not given'
                  2='(2) Actually given, completed'
                  3='(3) Actually given, not completed by admin.'
                  4='(4) Not completed client choice'
                  5='(5) Not completed no mention of choice'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q68_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q69_ser   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Not given'
                  2='(2) Actually given, completed'
                  6='(6) Planned or recom., can''t confirm if act.' ;
  VALUE q69_fac   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) Elsewhere' ;
  VALUE q70med    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE q71adm    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE q72dis    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE q73othr   -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE q74_meth  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE q74atot   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74agiv   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74anum   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74aplc   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here' 2='(2) At home' ;
  VALUE q74btot   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74bgiv   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74bnum   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74bplc   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Here'
                  2='(2) At home' 3='(3) Here/At Home' ;
  VALUE q75_home  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q76_dis   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Participant deceased' 2='(2) Completed planned treatment'
                  3='(3) Not complete, referred elsewhere'
                  4='(4) Not complete, administration choice'
                  5='(5) Not complete, participant choice'
                  6='(6) Not complete, choice not mentioned' 7='(7) Incarcerated'
                  8='(8) Other (SPECIFY REASON IN B)' ;
  VALUE q79sub    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q80_pln   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81aftr   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Services specified' ;
  VALUE q74a_yr   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q74b_yr   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q77_yr    -3='(-3) MISSING' ;
  VALUE q78_yr    -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q81a      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81d      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81e      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81f      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81g      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81h      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81i      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q81j      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q82aftr   -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) No treatment'
                  2='(2) Hospital inpatient' 3='(3) Residential'
                  4='(4) Outpatient/methadone maintenance' 5='(5) Other outpatient'
                  6='(6) Other (SPECIFY)' ;
  VALUE q83bill   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) Other (SPECIFY)' ;
  VALUE q83a_dol  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) None' 1='(1) $1-99' 2='(2) $100-499' 3='(3) $500-999'
                  4='(4) $1,000-4,999' 5='(5) $5,000-9,999' 6='(6) $10,000-14,999'
                  7='(7) $15,000-40,000' ;
  VALUE q83code   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED'
                  1='(1) Full amount billed' 2='(2) Sliding fee amount'
                  3='(3) Reduced amount: |___|___|% of full bill'
                  4='(4) Other (SPECIFY)' ;
  VALUE q83pcnt   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE q83b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q353cmnt  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE q33b1rcd  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) NO DIAGNOSIS (000.00)'
                  1='(1) ALC IND DISORD (291.00-291.99)'
                  2='(2) SUBST IND DISORD (292.00-292.99)'
                  3='(3) ALC INTOXICATION (303.00-303.89)'
                  4='(4) ALC DEPEND (303.90-303.99)'
                  5='(5) OPIOID DEPEND (304.00-304.09)'
                  6='(6) COCAINE DEPEND (304.20-304.29)'
                  7='(7) CANNABIS DEPEND (304.30-304.39)'
                  8='(8) OTH SUBST DEPEND (304.10-304.19,304.40-3'
                  9='(9) ALC ABUSE (305.00-305.09)'
                  10='(10) CANNABIS ABUSE (305.20-305.29)'
                  11='(11) OTH SUBST ABUSE (305.30-305.49, 305.70-3'
                  12='(12) OPIOID ABUSE (305.50-305.59)'
                  13='(13) COCAINE ABUSE (305.60-305.69)'
                  14='(14) MENTAL HEALTH CONDITION' 15='(15) OTHER CONDITION' ;
  VALUE q33b2rcd  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) NO DIAGNOSIS (000.00)'
                  1='(1) ALC IND DISORD (291.00-291.99)'
                  2='(2) SUBST IND DISORD (292.00-292.99)'
                  3='(3) ALC INTOXICATION (303.00-303.89)'
                  4='(4) ALC DEPEND (303.90-303.99)'
                  5='(5) OPIOID DEPEND (304.00-304.09)'
                  6='(6) COCAINE DEPEND (304.20-304.29)'
                  7='(7) CANNABIS DEPEND (304.30-304.39)'
                  8='(8) OTH SUBST DEPEND (304.10-304.19,304.40-3'
                  9='(9) ALC ABUSE (305.00-305.09)'
                  10='(10) CANNABIS ABUSE (305.20-305.29)'
                  11='(11) OTH SUBST ABUSE (305.30-305.49, 305.70-3'
                  12='(12) OPIOID ABUSE (305.50-305.59)'
                  13='(13) COCAINE ABUSE (305.60-305.69)'
                  14='(14) MENTAL HEALTH CONDITION' 15='(15) OTHER CONDITION' ;
  VALUE q33code   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) NO DIAGNOSIS (000.00)'
                  1='(1) ALC IND DISORD (291.00-291.99)'
                  2='(2) SUBST IND DISORD (292.00-292.99)'
                  3='(3) ALC INTOXICATION (303.00-303.89)'
                  4='(4) ALC DEPEND (303.90-303.99)'
                  5='(5) OPIOID DEPEND (304.00-304.09)'
                  6='(6) COCAINE DEPEND (304.20-304.29)'
                  7='(7) CANNABIS DEPEND (304.30-304.39)'
                  8='(8) OTH SUBST DEPEND (304.10-304.19,304.40-3'
                  9='(9) ALC ABUSE (305.00-305.09)'
                  10='(10) CANNABIS ABUSE (305.20-305.29)'
                  11='(11) OTH SUBST ABUSE (305.30-305.49, 305.70-3'
                  12='(12) OPIOID ABUSE (305.50-305.59)'
                  13='(13) COCAINE ABUSE (305.60-305.69)'
                  14='(14) MENTAL HEALTH CONDITION' 15='(15) OTHER CONDITION' ;
  VALUE q33rcode  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) NO DIAGNOSIS (000.00)'
                  1='(1) ALC IND DISORD (291.00-291.99)'
                  2='(2) SUBST IND DISORD (292.00-292.99)'
                  3='(3) ALC INTOXICATION (303.00-303.89)'
                  4='(4) ALC DEPEND (303.90-303.99)'
                  5='(5) OPIOID DEPEND (304.00-304.09)'
                  6='(6) COCAINE DEPEND (304.20-304.29)'
                  7='(7) CANNABIS DEPEND (304.30-304.39)'
                  8='(8) OTH SUBST DEPEND (304.10-304.19,304.40-3'
                  9='(9) ALC ABUSE (305.00-305.09)'
                  10='(10) CANNABIS ABUSE (305.20-305.29)'
                  11='(11) OTH SUBST ABUSE (305.30-305.49, 305.70-3'
                  12='(12) OPIOID ABUSE (305.50-305.59)'
                  13='(13) COCAINE ABUSE (305.60-305.69)'
                  14='(14) MENTAL HEALTH CONDITION' 15='(15) OTHER CONDITION' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CLIENTID <= -1) THEN CLIENTID = .;
   IF (FAC_ID <= -1) THEN FAC_ID = .;
   IF (MODE <= -1) THEN MODE = .;
   IF (UTYPE <= -1) THEN UTYPE = .;
   IF (ENVIRONM <= -1) THEN ENVIRONM = .;
   IF (DEAD <= -1) THEN DEAD = .;
   IF (RESP <= -1) THEN RESP = .;
   IF (CLIENTYP <= -1) THEN CLIENTYP = .;
   IF (Q3_WAIT <= -1) THEN Q3_WAIT = .;
   IF (Q4_PLAN <= -1) THEN Q4_PLAN = .;
   IF (Q5_PRIM <= -1) THEN Q5_PRIM = .;
   IF (Q6_PRIM <= -1) THEN Q6_PRIM = .;
   IF (Q7_SECN <= -1) THEN Q7_SECN = .;
   IF (Q10_AGE <= -1) THEN Q10_AGE = .;
   IF (Q11GEND <= -1) THEN Q11GEND = .;
   IF (Q12RACE <= -1) THEN Q12RACE = .;
   IF (Q13ETHN <= -1) THEN Q13ETHN = .;
   IF (Q14MSTA <= -1) THEN Q14MSTA = .;
   IF (Q15CHLD <= -1) THEN Q15CHLD = .;
   IF (Q16CHLV <= -1) THEN Q16CHLV = .;
   IF (Q17ARNG <= -1) THEN Q17ARNG = .;
   IF (Q18EDU <= -1) THEN Q18EDU = .;
   IF (Q19STU <= -1) THEN Q19STU = .;
   IF (Q20EMPL <= -1) THEN Q20EMPL = .;
   IF (Q22DWI <= -1) THEN Q22DWI = .;
   IF (Q23OTHR <= -1) THEN Q23OTHR = .;
   IF (Q24JAIL <= -1) THEN Q24JAIL = .;
   IF (Q25TRTMN <= -1) THEN Q25TRTMN = .;
   IF (Q26HOSP <= -1) THEN Q26HOSP = .;
   IF (Q27MED <= -1) THEN Q27MED = .;
   IF (Q28HIST <= -1) THEN Q28HIST = .;
   IF (Q29ABUSE <= -1) THEN Q29ABUSE = .;
   IF (Q30PREG <= -1) THEN Q30PREG = .;
   IF (Q31PROB <= -1) THEN Q31PROB = .;
   IF (Q32PRIN <= -1) THEN Q32PRIN = .;
   IF (Q34HIV <= -1) THEN Q34HIV = .;
   IF (Q34AINF <= -1) THEN Q34AINF = .;
   IF (Q35A <= -1) THEN Q35A = .;
   IF (Q35B <= -1) THEN Q35B = .;
   IF (Q35C <= -1) THEN Q35C = .;
   IF (Q36A <= -1) THEN Q36A = .;
   IF (Q36B <= -1) THEN Q36B = .;
   IF (Q36C <= -1) THEN Q36C = .;
   IF (Q37A <= -1) THEN Q37A = .;
   IF (Q37B <= -1) THEN Q37B = .;
   IF (Q37C <= -1) THEN Q37C = .;
   IF (Q38A <= -1) THEN Q38A = .;
   IF (Q38B <= -1) THEN Q38B = .;
   IF (Q38C <= -1) THEN Q38C = .;
   IF (Q39A <= -1) THEN Q39A = .;
   IF (Q39B <= -1) THEN Q39B = .;
   IF (Q39C <= -1) THEN Q39C = .;
   IF (Q40A <= -1) THEN Q40A = .;
   IF (Q40B <= -1) THEN Q40B = .;
   IF (Q40C <= -1) THEN Q40C = .;
   IF (Q41A <= -1) THEN Q41A = .;
   IF (Q41B <= -1) THEN Q41B = .;
   IF (Q41C <= -1) THEN Q41C = .;
   IF (Q42A <= -1) THEN Q42A = .;
   IF (Q42B <= -1) THEN Q42B = .;
   IF (Q42C <= -1) THEN Q42C = .;
   IF (Q43A <= -1) THEN Q43A = .;
   IF (Q43B <= -1) THEN Q43B = .;
   IF (Q43C <= -1) THEN Q43C = .;
   IF (Q44A <= -1) THEN Q44A = .;
   IF (Q44B <= -1) THEN Q44B = .;
   IF (Q44C <= -1) THEN Q44C = .;
   IF (Q45A <= -1) THEN Q45A = .;
   IF (Q45B <= -1) THEN Q45B = .;
   IF (Q45C <= -1) THEN Q45C = .;
   IF (Q46A <= -1) THEN Q46A = .;
   IF (Q46B <= -1) THEN Q46B = .;
   IF (Q46C <= -1) THEN Q46C = .;
   IF (Q47A <= -1) THEN Q47A = .;
   IF (Q47B <= -1) THEN Q47B = .;
   IF (Q47C <= -1) THEN Q47C = .;
   IF (Q48A <= -1) THEN Q48A = .;
   IF (Q48B <= -1) THEN Q48B = .;
   IF (Q48C <= -1) THEN Q48C = .;
   IF (Q49A <= -1) THEN Q49A = .;
   IF (Q49B <= -1) THEN Q49B = .;
   IF (Q49C <= -1) THEN Q49C = .;
   IF (Q50A <= -1) THEN Q50A = .;
   IF (Q50B <= -1) THEN Q50B = .;
   IF (Q50C <= -1) THEN Q50C = .;
   IF (Q51A <= -1) THEN Q51A = .;
   IF (Q51B <= -1) THEN Q51B = .;
   IF (Q51C <= -1) THEN Q51C = .;
   IF (Q52DRUG <= -1) THEN Q52DRUG = .;
   IF (Q53INT <= -1) THEN Q53INT = .;
   IF (Q53ADUSE <= -1) THEN Q53ADUSE = .;
   IF (Q53BFRE <= -1) THEN Q53BFRE = .;
   IF (Q54NUM <= -1) THEN Q54NUM = .;
   IF (Q55POSTV <= -1) THEN Q55POSTV = .;
   IF (Q56TEST <= -1) THEN Q56TEST = .;
   IF (Q56_T1 <= -1) THEN Q56_T1 = .;
   IF (Q56_T2 <= -1) THEN Q56_T2 = .;
   IF (Q56_MON1 <= -1) THEN Q56_MON1 = .;
   IF (Q56_DAY1 <= -1) THEN Q56_DAY1 = .;
   IF (Q56_YR1 <= -1) THEN Q56_YR1 = .;
   IF (Q56_MON2 <= -1) THEN Q56_MON2 = .;
   IF (Q56_DAY2 <= -1) THEN Q56_DAY2 = .;
   IF (Q56_YR2 <= -1) THEN Q56_YR2 = .;
   IF (Q56A1 <= -1) THEN Q56A1 = .;
   IF (Q56A2 <= -1) THEN Q56A2 = .;
   IF (Q56B1 <= -1) THEN Q56B1 = .;
   IF (Q56B2 <= -1) THEN Q56B2 = .;
   IF (Q56C1 <= -1) THEN Q56C1 = .;
   IF (Q56C2 <= -1) THEN Q56C2 = .;
   IF (Q56D1 <= -1) THEN Q56D1 = .;
   IF (Q56D2 <= -1) THEN Q56D2 = .;
   IF (Q56E1 <= -1) THEN Q56E1 = .;
   IF (Q56E2 <= -1) THEN Q56E2 = .;
   IF (Q56F1 <= -1) THEN Q56F1 = .;
   IF (Q56F2 <= -1) THEN Q56F2 = .;
   IF (Q56G1 <= -1) THEN Q56G1 = .;
   IF (Q56G2 <= -1) THEN Q56G2 = .;
   IF (Q56H1 <= -1) THEN Q56H1 = .;
   IF (Q56H2 <= -1) THEN Q56H2 = .;
   IF (Q56I1 <= -1) THEN Q56I1 = .;
   IF (Q56I2 <= -1) THEN Q56I2 = .;
   IF (Q56J1 <= -1) THEN Q56J1 = .;
   IF (Q56J2 <= -1) THEN Q56J2 = .;
   IF (Q56K1 <= -1) THEN Q56K1 = .;
   IF (Q56K2 <= -1) THEN Q56K2 = .;
   IF (Q56L1 <= -1) THEN Q56L1 = .;
   IF (Q56L2 <= -1) THEN Q56L2 = .;
   IF (Q56M1 <= -1) THEN Q56M1 = .;
   IF (Q56M2 <= -1) THEN Q56M2 = .;
   IF (Q56N1 <= -1) THEN Q56N1 = .;
   IF (Q56N2 <= -1) THEN Q56N2 = .;
   IF (Q56O1 <= -1) THEN Q56O1 = .;
   IF (Q56O2 <= -1) THEN Q56O2 = .;
   IF (Q57TOTN <= -1) THEN Q57TOTN = .;
   IF (Q57AYRN <= -1) THEN Q57AYRN = .;
   IF (Q58PAST <= -1) THEN Q58PAST = .;
   IF (Q58_PRA <= -1) THEN Q58_PRA = .;
   IF (Q58_SECA <= -1) THEN Q58_SECA = .;
   IF (Q58_FAA <= -1) THEN Q58_FAA = .;
   IF (Q58_REA <= -1) THEN Q58_REA = .;
   IF (Q58_PRB <= -1) THEN Q58_PRB = .;
   IF (Q58_SECB <= -1) THEN Q58_SECB = .;
   IF (Q58_FAB <= -1) THEN Q58_FAB = .;
   IF (Q58_REB <= -1) THEN Q58_REB = .;
   IF (Q58_PRC <= -1) THEN Q58_PRC = .;
   IF (Q58_SECC <= -1) THEN Q58_SECC = .;
   IF (Q58_FAC <= -1) THEN Q58_FAC = .;
   IF (Q58_REC <= -1) THEN Q58_REC = .;
   IF (Q58_PRD <= -1) THEN Q58_PRD = .;
   IF (Q58_SECD <= -1) THEN Q58_SECD = .;
   IF (Q58_FAD <= -1) THEN Q58_FAD = .;
   IF (Q58_RED <= -1) THEN Q58_RED = .;
   IF (Q58_PRE <= -1) THEN Q58_PRE = .;
   IF (Q58_SECE <= -1) THEN Q58_SECE = .;
   IF (Q58_FAE <= -1) THEN Q58_FAE = .;
   IF (Q58_REE <= -1) THEN Q58_REE = .;
   IF (Q58_PRF <= -1) THEN Q58_PRF = .;
   IF (Q58_SECF <= -1) THEN Q58_SECF = .;
   IF (Q58_FAF <= -1) THEN Q58_FAF = .;
   IF (Q58_REF <= -1) THEN Q58_REF = .;
   IF (Q58_PRG <= -1) THEN Q58_PRG = .;
   IF (Q58_SECG <= -1) THEN Q58_SECG = .;
   IF (Q58_FAG <= -1) THEN Q58_FAG = .;
   IF (Q58_REG <= -1) THEN Q58_REG = .;
   IF (Q58_PRH <= -1) THEN Q58_PRH = .;
   IF (Q58_SECH <= -1) THEN Q58_SECH = .;
   IF (Q58_FAH <= -1) THEN Q58_FAH = .;
   IF (Q58_REH <= -1) THEN Q58_REH = .;
   IF (Q58_PRI <= -1) THEN Q58_PRI = .;
   IF (Q58_SECI <= -1) THEN Q58_SECI = .;
   IF (Q58_FAI <= -1) THEN Q58_FAI = .;
   IF (Q58_REI <= -1) THEN Q58_REI = .;
   IF (Q58_PRJ <= -1) THEN Q58_PRJ = .;
   IF (Q58_SECJ <= -1) THEN Q58_SECJ = .;
   IF (Q58_FAJ <= -1) THEN Q58_FAJ = .;
   IF (Q58_REJ <= -1) THEN Q58_REJ = .;
   IF (Q59_SER <= -1) THEN Q59_SER = .;
   IF (Q59_FAC <= -1) THEN Q59_FAC = .;
   IF (Q59_NO <= -1) THEN Q59_NO = .;
   IF (Q60_SER <= -1) THEN Q60_SER = .;
   IF (Q60_FAC <= -1) THEN Q60_FAC = .;
   IF (Q60_NO <= -1) THEN Q60_NO = .;
   IF (Q61_SER <= -1) THEN Q61_SER = .;
   IF (Q61_FAC <= -1) THEN Q61_FAC = .;
   IF (Q61_NO <= -1) THEN Q61_NO = .;
   IF (Q62_SER <= -1) THEN Q62_SER = .;
   IF (Q62_FAC <= -1) THEN Q62_FAC = .;
   IF (Q62_NO <= -1) THEN Q62_NO = .;
   IF (Q63_SER <= -1) THEN Q63_SER = .;
   IF (Q63_FAC <= -1) THEN Q63_FAC = .;
   IF (Q64_SER <= -1) THEN Q64_SER = .;
   IF (Q64_FAC <= -1) THEN Q64_FAC = .;
   IF (Q65_SER <= -1) THEN Q65_SER = .;
   IF (Q65_FAC <= -1) THEN Q65_FAC = .;
   IF (Q66_SER <= -1) THEN Q66_SER = .;
   IF (Q66_FAC <= -1) THEN Q66_FAC = .;
   IF (Q67_SER <= -1) THEN Q67_SER = .;
   IF (Q67_FAC <= -1) THEN Q67_FAC = .;
   IF (Q68_SER <= -1) THEN Q68_SER = .;
   IF (Q68_FAC <= -1) THEN Q68_FAC = .;
   IF (Q69_SER <= -1) THEN Q69_SER = .;
   IF (Q69_FAC <= -1) THEN Q69_FAC = .;
   IF (Q70MED <= -1) THEN Q70MED = .;
   IF (Q71ADM <= -1) THEN Q71ADM = .;
   IF (Q72DIS <= -1) THEN Q72DIS = .;
   IF (Q73OTHR <= -1) THEN Q73OTHR = .;
   IF (Q74_METH <= -1) THEN Q74_METH = .;
   IF (Q74ATOT <= -1) THEN Q74ATOT = .;
   IF (Q74AGIV <= -1) THEN Q74AGIV = .;
   IF (Q74ANUM <= -1) THEN Q74ANUM = .;
   IF (Q74APLC <= -1) THEN Q74APLC = .;
   IF (Q74BTOT <= -1) THEN Q74BTOT = .;
   IF (Q74BGIV <= -1) THEN Q74BGIV = .;
   IF (Q74BNUM <= -1) THEN Q74BNUM = .;
   IF (Q74BPLC <= -1) THEN Q74BPLC = .;
   IF (Q75_HOME <= -1) THEN Q75_HOME = .;
   IF (Q76_DIS <= -1) THEN Q76_DIS = .;
   IF (Q79SUB <= -1) THEN Q79SUB = .;
   IF (Q80_PLN <= -1) THEN Q80_PLN = .;
   IF (Q81AFTR <= -1) THEN Q81AFTR = .;
   IF (Q74A_YR <= -1) THEN Q74A_YR = .;
   IF (Q74B_YR <= -1) THEN Q74B_YR = .;
   IF (Q77_YR <= -1) THEN Q77_YR = .;
   IF (Q78_YR <= -1) THEN Q78_YR = .;
   IF (Q81A <= -1) THEN Q81A = .;
   IF (Q81B <= -1) THEN Q81B = .;
   IF (Q81C <= -1) THEN Q81C = .;
   IF (Q81D <= -1) THEN Q81D = .;
   IF (Q81E <= -1) THEN Q81E = .;
   IF (Q81F <= -1) THEN Q81F = .;
   IF (Q81G <= -1) THEN Q81G = .;
   IF (Q81H <= -1) THEN Q81H = .;
   IF (Q81I <= -1) THEN Q81I = .;
   IF (Q81J <= -1) THEN Q81J = .;
   IF (Q82AFTR <= -1) THEN Q82AFTR = .;
   IF (Q83BILL <= -1) THEN Q83BILL = .;
   IF (Q83A_DOL <= -1) THEN Q83A_DOL = .;
   IF (Q83CODE <= -1) THEN Q83CODE = .;
   IF (Q83PCNT <= -1) THEN Q83PCNT = .;
   IF (Q83B <= -1) THEN Q83B = .;
   IF (Q353CMNT <= -1) THEN Q353CMNT = .;
   IF (Q33B1RCD <= -1) THEN Q33B1RCD = .;
   IF (Q33B2RCD <= -1) THEN Q33B2RCD = .;
   IF (Q33CODE <= -1) THEN Q33CODE = .;
   IF (Q33RCODE <= -1) THEN Q33RCODE = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT MODE mode. UTYPE utype. ENVIRONM environm.
         DEAD dead. RESP resp. DISP disp.
         CLIENTYP clientyp. Q3_WAIT q3_wait. Q4_PLAN q4_plan.
         Q5_PRIM q5_prim. Q6_PRIM q6_prim. Q7_SECN q7_secn.
         Q10_AGE q10_age. Q11GEND q11gend. Q12RACE q12race.
         Q13ETHN q13ethn. Q14MSTA q14msta. Q15CHLD q15chld.
         Q16CHLV q16chlv. Q17ARNG q17arng. Q18EDU q18edu.
         Q19STU q19stu. Q20EMPL q20empl. Q22DWI q22dwi.
         Q23OTHR q23othr. Q24JAIL q24jail. Q25TRTMN q25trtmn.
         Q26HOSP q26hosp. Q27MED q27med. Q28HIST q28hist.
         Q29ABUSE q29abuse. Q30PREG q30preg. Q31PROB q31prob.
         Q32PRIN q32prin. Q34HIV q34hiv. Q34AINF q34ainf.
         Q35A q35a. Q35B q35b. Q35C q35c.
         Q36A q36a. Q36B q36b. Q36C q36c.
         Q37A q37a. Q37B q37b. Q37C q37c.
         Q38A q38a. Q38B q38b. Q38C q38c.
         Q39A q39a. Q39B q39b. Q39C q39c.
         Q40A q40a. Q40B q40b. Q40C q40c.
         Q41A q41a. Q41B q41b. Q41C q41c.
         Q42A q42a. Q42B q42b. Q42C q42c.
         Q43A q43a. Q43B q43b. Q43C q43c.
         Q44A q44a. Q44B q44b. Q44C q44c.
         Q45A q45a. Q45B q45b. Q45C q45c.
         Q46A q46a. Q46B q46b. Q46C q46c.
         Q47A q47a. Q47B q47b. Q47C q47c.
         Q48A q48a. Q48B q48b. Q48C q48c.
         Q49A q49a. Q49B q49b. Q49C q49c.
         Q50A q50a. Q50B q50b. Q50C q50c.
         Q51A q51a. Q51B q51b. Q51C q51c.
         Q52DRUG q52drug. Q53INT q53int. Q53ADUSE q53aduse.
         Q53BFRE q53bfre. Q54NUM q54num. Q55POSTV q55postv.
         Q56TEST q56test. Q56_T1 q56_t1ff. Q56_T2 q56_t2ff.
         Q56_MON1 q56_monf. Q56_DAY1 q56_dayf. Q56_YR1 q56_yr1f.
         Q56_MON2 q56_mo0f. Q56_DAY2 q56_da0f. Q56_YR2 q56_yr2f.
         Q56A1 q56a1fff. Q56A2 q56a2fff. Q56B1 q56b1fff.
         Q56B2 q56b2fff. Q56C1 q56c1fff. Q56C2 q56c2fff.
         Q56D1 q56d1fff. Q56D2 q56d2fff. Q56E1 q56e1fff.
         Q56E2 q56e2fff. Q56F1 q56f1fff. Q56F2 q56f2fff.
         Q56G1 q56g1fff. Q56G2 q56g2fff. Q56H1 q56h1fff.
         Q56H2 q56h2fff. Q56I1 q56i1fff. Q56I2 q56i2fff.
         Q56J1 q56j1fff. Q56J2 q56j2fff. Q56K1 q56k1fff.
         Q56K2 q56k2fff. Q56L1 q56l1fff. Q56L2 q56l2fff.
         Q56M1 q56m1fff. Q56M2 q56m2fff. Q56N1 q56n1fff.
         Q56N2 q56n2fff. Q56O1 q56o1fff. Q56O2 q56o2fff.
         Q57TOTN q57totn. Q57AYRN q57ayrn. Q58PAST q58past.
         Q58_PRA q58_pra. Q58_SECA q58_seca. Q58_FAA q58_faa.
         Q58_REA q58_rea. Q58_PRB q58_prb. Q58_SECB q58_secb.
         Q58_FAB q58_fab. Q58_REB q58_reb. Q58_PRC q58_prc.
         Q58_SECC q58_secc. Q58_FAC q58_fac. Q58_REC q58_rec.
         Q58_PRD q58_prd. Q58_SECD q58_secd. Q58_FAD q58_fad.
         Q58_RED q58_red. Q58_PRE q58_pre. Q58_SECE q58_sece.
         Q58_FAE q58_fae. Q58_REE q58_ree. Q58_PRF q58_prf.
         Q58_SECF q58_secf. Q58_FAF q58_faf. Q58_REF q58_ref.
         Q58_PRG q58_prg. Q58_SECG q58_secg. Q58_FAG q58_fag.
         Q58_REG q58_reg. Q58_PRH q58_prh. Q58_SECH q58_sech.
         Q58_FAH q58_fah. Q58_REH q58_reh. Q58_PRI q58_pri.
         Q58_SECI q58_seci. Q58_FAI q58_fai. Q58_REI q58_rei.
         Q58_PRJ q58_prj. Q58_SECJ q58_secj. Q58_FAJ q58_faj.
         Q58_REJ q58_rej. Q59_SER q59_ser. Q59_FAC q59_fac.
         Q59_NO q59_no. Q60_SER q60_ser. Q60_FAC q60_fac.
         Q60_NO q60_no. Q61_SER q61_ser. Q61_FAC q61_fac.
         Q61_NO q61_no. Q62_SER q62_ser. Q62_FAC q62_fac.
         Q62_NO q62_no. Q63_SER q63_ser. Q63_FAC q63_fac.
         Q64_SER q64_ser. Q64_FAC q64_fac. Q65_SER q65_ser.
         Q65_FAC q65_fac. Q66_SER q66_ser. Q66_FAC q66_fac.
         Q67_SER q67_ser. Q67_FAC q67_fac. Q68_SER q68_ser.
         Q68_FAC q68_fac. Q69_SER q69_ser. Q69_FAC q69_fac.
         Q70MED q70med. Q71ADM q71adm. Q72DIS q72dis.
         Q73OTHR q73othr. Q74_METH q74_meth. Q74ATOT q74atot.
         Q74AGIV q74agiv. Q74ANUM q74anum. Q74APLC q74aplc.
         Q74BTOT q74btot. Q74BGIV q74bgiv. Q74BNUM q74bnum.
         Q74BPLC q74bplc. Q75_HOME q75_home. Q76_DIS q76_dis.
         Q79SUB q79sub. Q80_PLN q80_pln. Q81AFTR q81aftr.
         Q74A_YR q74a_yr. Q74B_YR q74b_yr. Q77_YR q77_yr.
         Q78_YR q78_yr. Q81A q81a. Q81B q81b.
         Q81C q81c. Q81D q81d. Q81E q81e.
         Q81F q81f. Q81G q81g. Q81H q81h.
         Q81I q81i. Q81J q81j. Q82AFTR q82aftr.
         Q83BILL q83bill. Q83A_DOL q83a_dol. Q83CODE q83code.
         Q83PCNT q83pcnt. Q83B q83b. Q353CMNT q353cmnt.
         Q33B1RCD q33b1rcd. Q33B2RCD q33b2rcd. Q33CODE q33code.
         Q33RCODE q33rcode.  ;

RUN ;
